# TableColumnProperties

The properties of a column in a table.

**Type:** object

## Properties

- **widthType** (enum): The width type of the column.
- **width** ([Dimension](dimension.md)): The width of the column. Set when the column's `width_type` is FIXED_WIDTH.
